# -*- coding: utf-8 -*-

"""MATHEMATICS ROUTINES.

This module contains submodules for mathematical applications.

:Author: Samuel Farrens <samuel.farrens@cea.fr>

"""

__all__ = ['convolve', 'matrix', 'stats', 'metrics']
